@@ -17,7 +17,10 @@ from argparse import ArgumentParser
 from clint import args
 from clint.textui import colored, columns, indent, puts, puts_err
 from getpass import getpass
-from os import chmod
+from os import chmod, rename
+from os.path import exists
+from pydoc import pipepager
+from StringIO import StringIO
 from sys import exit
 
 
@@ -245,6 +248,44 @@ def _prompt(message, default=None):
     return ret_val
 
 
+def backlog(arguments):
+    """List backlog stories.
+
+    :param arguments: Command line arguments.
+    """
+    git = _git()
+    token = _get_value(git, "pivotal", "api-token")
+    pt = PivotalTracker(token)
+    project_id = _get_value(git, "pivotal", "project-id")
+    project = pt.get_project(project_id)
+    stories = pt.get_backlog(project.id)
+    output = StringIO()
+
+    for story in stories:
+        if story.state in [Story.STATE_UNSCHEDULED, Story.STATE_UNSTARTED]:
+            id = colored.yellow(str(story.id))
+
+            if story.estimate is None:
+                type = story.type.upper()
+            elif story.estimate >= 0:
+                type = "{0} ({1:d})".format(story.type.upper(), story.estimate)
+            else:
+                type = "{0} (?)".format(story.type.upper())
+
+            name = story.name
+
+            if story.owner:
+                for member in project.members:
+                    if member.name == story.owner:
+                        name = "{0} ({1})".format(story.name, member.initials)
+                        break
+
+            message = "{0} {1}: {2}\n".format(id, type, name)
+            output.write(message)
+
+    pipepager(output.getvalue(), cmd="less -FRSX")
+
+
 def finish(arguments):
     """Finish a story branch.
 
@@ -337,7 +378,7 @@ def init(arguments):
     aliases = {}
 
     for command, function in commands.iteritems():
-        if not command.startswith('-'):
+        if not (command.startswith("--") or function.__name__.startswith('_')):
             alias = "continuity" if command == "init" else command
             command = "!continuity {0} \"$@\"".format(function.func_name)
             aliases[alias] = command
@@ -352,6 +393,12 @@ def init(arguments):
 
     filename = "{0}/hooks/prepare-commit-msg".format(git.repo.git_dir)
 
+    if exists(filename):
+        backup = "{0}.bak".format(filename)
+
+        if not exists(backup):
+            rename(filename, backup)
+
     with open(filename, 'w') as hook:
         hook.write('#!/bin/sh\n\ncontinuity commit "$@"')
 
@@ -367,6 +414,10 @@ def main():
     if command in commands:
         args.remove(command)
         commands[command].__call__(args)
+    else:
+        message = "continuity: '{0}' is not a continuity command. See 'continuity --help'."  # noqa
+        puts(message.format(command))
+        exit(1)
 
 
 def review(arguments):
@@ -397,7 +448,7 @@ def review(arguments):
         branch = _get_value(git, "continuity", "integration-branch")
         pull_request = github.create_pull_request(title, description,
                 branch)
-        puts("Opened pull request: {0}".format(pull_request["url"]))
+        puts("Opened pull request: {0}".format(pull_request["html_url"]))
     except GitHubException:
         puts_err("Unable to create pull request.")
         exit(128)
@@ -411,6 +462,9 @@ def start(arguments):
 
     :param arguments: Command line arguments.
     """
+    parser = ArgumentParser()
+    parser.add_argument("-m", "--mywork", action="store_true")
+    namespace = parser.parse_args(arguments.all)
     git = _git()
     token = _get_value(git, "pivotal", "api-token")
     pt = PivotalTracker(token)
@@ -421,7 +475,7 @@ def start(arguments):
     project_id = _get_value(git, "pivotal", "project-id")
     story = pt.get_story(project_id, filter)
 
-    if not story:
+    if not (story or namespace.mywork):
         filter = "state:unstarted"
         story = pt.get_story(project_id, filter)
 
@@ -435,6 +489,7 @@ def start(arguments):
         if story.owner == owner:
             try:
                 name = _prompt("Enter branch name")
+                name = '-'.join(name.split())
                 git.create_branch(name)
                 git.set_configuration("branch", name, story=story.id)
                 pt.set_story(project_id, story.id, "started")
@@ -445,7 +500,10 @@ def start(arguments):
         else:
             puts("Unable to update story owner.")
     else:
-        puts("No estimated stories found in the backlog.")
+        if namespace.mywork:
+            puts("No estimated stories found in my work.")
+        else:
+            puts("No estimated stories found in the backlog.")
 
 
 def story(arguments):
@@ -465,11 +523,13 @@ def story(arguments):
         puts(story.name)
         puts()
 
-        if story.estimate:
+        if story.estimate is None:
+            puts(story.type.capitalize())
+        elif story.estimate >= 0:
             puts("{0} Estimate: {1:d} points".format(story.type.capitalize(),
                 story.estimate))
         else:
-            puts(story.type.capitalize())
+            puts("{0} Unestimated.".format(story.type.capitalize()))
 
         if story.description:
             puts()
@@ -526,6 +586,7 @@ def version(arguments):
 commands = {
     "--help": help,
     "--version": version,
+    "backlog": backlog,
     "commit": _commit,
     "finish": finish,
     "init": init,
